@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import (
     ListTableColumnsPaginator,
@@ -76,25 +76,33 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class HoneycodeClient:
+class HoneycodeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        HoneycodeClient exceptions.
+        """
 
     def batch_create_table_rows(
         self,
         *,
         workbookId: str,
         tableId: str,
-        rowsToCreate: List[CreateRowDataTypeDef],
+        rowsToCreate: List["CreateRowDataTypeDef"],
         clientRequestToken: str = None
     ) -> BatchCreateTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.batch_create_table_rows)
+        The BatchCreateTableRows API allows you to create one or more rows at the end of
+        a table in a workbook.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.batch_create_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_create_table_rows)
         """
 
@@ -102,7 +110,10 @@ class HoneycodeClient:
         self, *, workbookId: str, tableId: str, rowIds: List[str], clientRequestToken: str = None
     ) -> BatchDeleteTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.batch_delete_table_rows)
+        The BatchDeleteTableRows API allows you to delete one or more rows from a table
+        in a workbook.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.batch_delete_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_delete_table_rows)
         """
 
@@ -111,11 +122,14 @@ class HoneycodeClient:
         *,
         workbookId: str,
         tableId: str,
-        rowsToUpdate: List[UpdateRowDataTypeDef],
+        rowsToUpdate: List["UpdateRowDataTypeDef"],
         clientRequestToken: str = None
     ) -> BatchUpdateTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.batch_update_table_rows)
+        The BatchUpdateTableRows API allows you to update one or more rows in a table in
+        a workbook.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.batch_update_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_update_table_rows)
         """
 
@@ -124,17 +138,21 @@ class HoneycodeClient:
         *,
         workbookId: str,
         tableId: str,
-        rowsToUpsert: List[UpsertRowDataTypeDef],
+        rowsToUpsert: List["UpsertRowDataTypeDef"],
         clientRequestToken: str = None
     ) -> BatchUpsertTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.batch_upsert_table_rows)
+        The BatchUpsertTableRows API allows you to upsert one or more rows in a table.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.batch_upsert_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_upsert_table_rows)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#can_paginate)
         """
 
@@ -142,7 +160,10 @@ class HoneycodeClient:
         self, *, workbookId: str, tableId: str, jobId: str
     ) -> DescribeTableDataImportJobResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.describe_table_data_import_job)
+        The DescribeTableDataImportJob API allows you to retrieve the status and details
+        of a table data import job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.describe_table_data_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#describe_table_data_import_job)
         """
 
@@ -154,7 +175,9 @@ class HoneycodeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#generate_presigned_url)
         """
 
@@ -164,12 +187,14 @@ class HoneycodeClient:
         workbookId: str,
         appId: str,
         screenId: str,
-        variables: Dict[str, VariableValueTypeDef] = None,
+        variables: Dict[str, "VariableValueTypeDef"] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> GetScreenDataResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.get_screen_data)
+        The GetScreenData API allows retrieval of data from a screen in a Honeycode app.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.get_screen_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get_screen_data)
         """
 
@@ -180,12 +205,15 @@ class HoneycodeClient:
         appId: str,
         screenId: str,
         screenAutomationId: str,
-        variables: Dict[str, VariableValueTypeDef] = None,
+        variables: Dict[str, "VariableValueTypeDef"] = None,
         rowId: str = None,
         clientRequestToken: str = None
     ) -> InvokeScreenAutomationResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.invoke_screen_automation)
+        The InvokeScreenAutomation API allows invoking an action defined in a screen in
+        a Honeycode app.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.invoke_screen_automation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#invoke_screen_automation)
         """
 
@@ -193,7 +221,10 @@ class HoneycodeClient:
         self, *, workbookId: str, tableId: str, nextToken: str = None
     ) -> ListTableColumnsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.list_table_columns)
+        The ListTableColumns API allows you to retrieve a list of all the columns in a
+        table in a workbook.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.list_table_columns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_table_columns)
         """
 
@@ -207,7 +238,10 @@ class HoneycodeClient:
         nextToken: str = None
     ) -> ListTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.list_table_rows)
+        The ListTableRows API allows you to retrieve a list of all the rows in a table
+        in a workbook.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.list_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_table_rows)
         """
 
@@ -215,7 +249,10 @@ class HoneycodeClient:
         self, *, workbookId: str, maxResults: int = None, nextToken: str = None
     ) -> ListTablesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.list_tables)
+        The ListTables API allows you to retrieve a list of all the tables in a
+        workbook.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.list_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_tables)
         """
 
@@ -229,7 +266,10 @@ class HoneycodeClient:
         nextToken: str = None
     ) -> QueryTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.query_table_rows)
+        The QueryTableRows API allows you to use a filter formula to query for specific
+        rows in a table.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.query_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#query_table_rows)
         """
 
@@ -244,7 +284,9 @@ class HoneycodeClient:
         clientRequestToken: str
     ) -> StartTableDataImportJobResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Client.start_table_data_import_job)
+        The StartTableDataImportJob API allows you to start an import job on a table.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Client.start_table_data_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#start_table_data_import_job)
         """
 
@@ -253,23 +295,27 @@ class HoneycodeClient:
         self, operation_name: Literal["list_table_columns"]
     ) -> ListTableColumnsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_table_rows"]) -> ListTableRowsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Paginator.ListTables)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Paginator.ListTables)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_table_rows"]) -> QueryTableRowsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
         """
